#
# spec file for package pocl
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Guillaume GARDET <guillaume@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pocl
Summary:        Portable Computing Language - an OpenCL implementation
License:        MIT
Group:          Productivity/Other
Version:        0.13
Release:        3.20
# The whole code is under MIT
# except include/utlist.h which is under BSD (and unbundled) and
# except lib/kernel/vecmath which is under GPLv3+ or LGPLv3+ (and unbundled in future)
Url:            http://portablecl.org/
Source0:        http://portablecl.org/downloads/%{name}-%{version}.tar.gz
Source99:       pocl-rpmlintrc
Patch0:         0001-Fixes-357-broken-build-with-GCC-6.1.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Only armv7l is supported
# PPC support is currently broken, due to path problems
# s390(x) and aarch64 also not supported, so use ExclusiveArch
ExclusiveArch:  %{ix86} x86_64 armv7l armv7hl
BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.8.12
BuildRequires:  libtool
BuildRequires:  libtool-ltdl-devel
BuildRequires:  llvm > 3.5
BuildRequires:  llvm-clang > 3.5
BuildRequires:  llvm-clang-devel > 3.5
BuildRequires:  llvm-devel > 3.5
BuildRequires:  ncurses-devel
BuildRequires:  opencl-headers
BuildRequires:  pkgconfig
BuildRequires:  uthash-devel
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(hwloc)
#BuildRequires:	vecmath-devel
Requires:       libstdc++-devel
Requires:       llvm-clang > 3.5
Requires:       uthash

%description
Portable Computing Language (pocl) aims to become a MIT-licensed open source
implementation of the OpenCL standard which can be easily adapted for new targets
and devices, both for homogeneous CPU and heterogenous GPUs/accelerators.

pocl uses Clang as an OpenCL C frontend and LLVM for the kernel compiler
implementation, and as a portability layer. Thus, if your desired target
has an LLVM backend, it should be able to get OpenCL support easily by using pocl.

The goal is to accomplish improved performance portability using a kernel
compiler that can generate multi-work-item work-group functions that exploit
various types of parallel hardware resources: VLIW, superscalar, SIMD, SIMT,
multicore, multithread ...

Additional purpose of the project is to serve as a research platform for
issues in parallel programming on heterogeneous platforms.


%package devel
Summary:        Portable Computing Language - development files
Group:          Development/Languages/Other 
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       opencl-headers

%description devel
Portable Computing Language (pocl) aims to become a MIT-licensed open source
implementation of the OpenCL standard which can be easily adapted for new targets
and devices, both for homogeneous CPU and heterogenous GPUs/accelerators.

This Subpackage provides the development files needed for pocl.


%prep
%setup -q
%patch0 -p1

%build
mkdir build
cd build
cmake ..\
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DCMAKE_C_COMPILER=clang  \
  -DCMAKE_CXX_COMPILER=clang++ \
  -DWITH_LLVM_CONFIG=/usr/bin/llvm-config
make %{?_smp_mflags}

# docs
#cd doc/sphinx
#make html

%install
%cmake_install

# FIXME - should be handled upstream
chmod 755 %{buildroot}/%{_bindir}/pocl-standalone

# Unbundle vecmath
#rm -vf %{buildroot}/%{_libdir}/pocl/vecmath/
#ln -vs %{_includedir}/vecmath %{buildroot}/%{_libdir}/pocl/vecmath
# <visit0r> but you need to run the .py to generate the files under the pocl dir

%check
cd build
ctest %{?_smp_mflags} ||:

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc CHANGES README doc/sphinx/source/*.rst
%dir %{_sysconfdir}/OpenCL/
%dir %{_sysconfdir}/OpenCL/vendors
%{_sysconfdir}/OpenCL/vendors/pocl.icd
%{_bindir}/pocl-standalone
%{_libdir}/libpocl.so.*
%{_libdir}/libpoclu.so.*
%{_libdir}/pocl/
%{_datadir}/pocl/

%files devel
%defattr(-,root,root)
%{_libdir}/libpoclu.so
%{_libdir}/libpocl.so
%{_libdir}/pkgconfig/pocl.pc
%{_includedir}/poclu.h

%changelog
* Mon Jul  4 2016 mardnh@gmx.de
- Add patch: 0001-Fixes-357-broken-build-with-GCC-6.1.patch
  * Fix build with GCC 6.x
* Tue Apr  5 2016 mpluskal@suse.com
- Update to 0.13
  * kernel compiler support for LLVM/Clang 3.8
  * initial (partial) OpenCL 2.0 support
  * CMake build system almost on parity with autotools
  * Improved HSA support
  * Other optimizations and bug fixes
* Mon Oct 26 2015 mardnh@gmx.de
- update to version 0.12
  Highlights
  * Support for HSA-compliant devices (kernel agents). The GPU of AMD Kaveri
    now works through pocl with a bunch of test cases in the AMD SDK 2.9 example
    suite.
  * New and improved kernel cache system that enables caching
    kernels with #includes.
  * Support for LLVM/Clang 3.7.
  * Little endian MIPS32 now passes almost all pocl testsuite tests.
  OpenCL Runtime/Platform API support
  * Transferred buffer read/write/copy offset calculation to device driver side.
  - these driver api functions have changed; got offset as a new argument.
  * Maximum allocation is not limited to 1/4th of total memory size.
  * Maximum image dimensions grow to fit maximum allocation.
  * clGetDeviceInfo() reports better information about CPU vendor and cache.
  * experimental clCreateSubDevices() for pthread CPU device.
  OpenCL C Builtin Function Implementations
  * Implemented get_image_dim().
  Bugfixes
  * Avoid infinite loops when users recycle an event waiting list.
  * Correctly report the base address alignment.
  * Lots of others.
  Misc
  * Tests now using new cl2.hpp, removing dependency on OpenGL headers
- remove OpenGL-related packages from BuildRequires
- add rpmlintrc
* Wed Jul  1 2015 cdenicolo@suse.com
- license update: MIT
  overall license is MIT, other licenses refere to build scripts only.
* Thu Mar 12 2015 mardnh@gmx.de
- update to version 0.11
  This release adds:
  * kernel compiler support for LLVM/Clang 3.6,
  * caching of compiled OpenCL kernels
  * initial Android support
  * experimental Windows support (many things still broken there)
  * two new examples, Cloverleaf and Halide, updated AMDSDK examples
  * better debugging possibilities
  * initial MIPS architecture support
* Tue Oct  7 2014 mardnh@gmx.de
- initial stable package, version 0.10
  based on home:mnhauke:opencl:testing/pocl
